import world
from world.player import nanny


def syslog(message):
    print message
mudlog = syslog

def bridgeModule():
    return world

def iterateOLCAccessByName(name):
    return []


